package com.ruoyi.tcZz.controller;

import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcAqg;
import com.ruoyi.tcZz.service.ITcAqgService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.FileInputStream;
import java.util.List;

/**
 * 网络安全官Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@Api(tags = "网络安全官")
@RestController
@RequestMapping("/tcZz/networkEcology/aqg")
public class TcAqgController extends BaseController {
    @Autowired
    private ITcAqgService tcAqgService;

    /**
     * 查询网络安全官列表
     */
    @ApiOperation(value = "查询网络安全官列表", response = TcAqg.class)
    @GetMapping("/list")
    public TableDataInfo list(TcAqg tcAqg) {
        startPage();
        List<TcAqg> list = tcAqgService.selectTcAqgList(tcAqg);
        return getDataTable(list);
    }

    /**
     * 导出网络安全官列表
     */
    @ApiOperation(value = "导出网络安全官列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcAqg tcAqg) {
        List<TcAqg> list = tcAqgService.selectTcAqgList(tcAqg);
        ExcelUtil<TcAqg> util = new ExcelUtil<TcAqg>(TcAqg.class);
        util.exportExcel(response, list, "网络安全官数据");
    }

    /**
     * 获取网络安全官详细信息
     */
    @ApiOperation(value = "获取网络安全官详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcAqgService.selectTcAqgById(id));
    }

    /**
     * 新增网络安全官
     */
    @ApiOperation(value = "新增网络安全官")
    @PostMapping
    public AjaxResult add(@RequestBody TcAqg tcAqg) {
        return toAjax(tcAqgService.insertTcAqg(tcAqg));
    }

    /**
     * 修改网络安全官
     */
    @ApiOperation(value = "修改网络安全官")
    @PutMapping
    public AjaxResult edit(@RequestBody TcAqg tcAqg) {
        return toAjax(tcAqgService.updateTcAqg(tcAqg));
    }

    /**
     * 删除网络安全官
     */
    @ApiOperation(value = "删除网络安全官")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcAqgService.deleteTcAqgByIds(ids));
    }

    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcAqg> util = new ExcelUtil<TcAqg>(TcAqg.class);
        List<TcAqg> tcAqgList = util.importExcel(file.getInputStream());
        tcAqgService.importUser(tcAqgList);
        return AjaxResult.success();
    }


    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcAqgService.updateByisStatus(isStatus, ids);
        return AjaxResult.success();
    }
    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcAqg> util = new ExcelUtil<TcAqg>(TcAqg.class);
        util.importTemplateExcel(response, " 网络安全官");
    }

}
