package com.ruoyi.tcZz.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcBzhan;
import com.ruoyi.tcZz.domain.TcCy;
import com.ruoyi.tcZz.domain.TcWljg;
import com.ruoyi.tcZz.service.ITcCyService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 词云Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api(tags = "词云")
@RequestMapping("/tcZz/netWorkYq/cy")
public class TcCyController extends BaseController {
    @Autowired
    private ITcCyService tcCyService;

    /**
     * 导出词云列表
     */
    @ApiOperation(value = "导出词云列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcCy tcCy) {
        List<TcCy> list = tcCyService.selectTcCyList(tcCy);
        ExcelUtil<TcCy> util = new ExcelUtil<TcCy>(TcCy.class);
        util.exportExcel(response, list, "词云数据");
    }

    /**
     * 获取词云详细信息
     */
    @ApiOperation(value = "获取词云详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcCyService.selectTcCyById(id));
    }

    /**
     * 新增词云
     */
    @ApiOperation(value = "新增词云")
    @PostMapping
    public AjaxResult add(@RequestBody TcCy tcCy) {
        return toAjax(tcCyService.insertTcCy(tcCy));
    }

    /**
     * 修改词云
     */
    @ApiOperation(value = "修改词云")
    @PutMapping
    public AjaxResult edit(@RequestBody TcCy tcCy) {
        return toAjax(tcCyService.updateTcCy(tcCy));
    }

    /**
     * 删除词云
     */
    @ApiOperation(value = "删除词云")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcCyService.deleteTcCyByIds(ids));
    }


    /**
     * 查询词云列表
     */
    @ApiOperation(value = "查询词云列表", response = TcCy.class)
    @GetMapping("/ListNoToken")
    public TableDataInfo ListNoToken(TcCy tcCy) {
        startPage();
        List<TcCy> list = tcCyService.selectTcCyList(tcCy);
        return getDataTable(list);
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcCy> util = new ExcelUtil<TcCy>(TcCy.class);
        List<TcCy> tcCyList = util.importExcel(file.getInputStream());
        tcCyService.importUser(tcCyList);
        return AjaxResult.success();
    }
    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcCyService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcCy> util = new ExcelUtil<TcCy>(TcCy.class);
        util.importTemplateExcel(response, " 词云列表");
    }
}
