package com.ruoyi.tcZz.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcCy;
import com.ruoyi.tcZz.domain.TcDbdw;
import com.ruoyi.tcZz.domain.TcWljg;
import com.ruoyi.tcZz.service.ITcDbdwService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 等保单位Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api(tags = "等保单位")
@RequestMapping("/tcZz/networkSecurity/dbdw")
public class TcDbdwController extends BaseController {
    @Autowired
    private ITcDbdwService tcDbdwService;

    /**
     * 查询等保单位列表
     */
    @ApiOperation(value = "等保单位", response = TcDbdw.class)
    @GetMapping("/list")
    public TableDataInfo list(TcDbdw tcDbdw) {
        startPage();
        List<TcDbdw> list = tcDbdwService.selectTcDbdwList(tcDbdw);
        return getDataTable(list);
    }

    /**
     * 导出等保单位列表
     */
    @ApiOperation(value = "导出等保单位列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcDbdw tcDbdw) {
        List<TcDbdw> list = tcDbdwService.selectTcDbdwList(tcDbdw);
        ExcelUtil<TcDbdw> util = new ExcelUtil<TcDbdw>(TcDbdw.class);
        util.exportExcel(response, list, "等保单位数据");
    }

    /**
     * 获取等保单位详细信息
     */
    @ApiOperation(value = "获取等保单位详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcDbdwService.selectTcDbdwById(id));
    }

    /**
     * 新增等保单位
     */
    @ApiOperation(value = "新增等保单位")
    @PostMapping
    public AjaxResult add(@RequestBody TcDbdw tcDbdw) {
        return toAjax(tcDbdwService.insertTcDbdw(tcDbdw));
    }

    /**
     * 修改等保单位
     */
    @ApiOperation(value = "修改等保单位")
    @PutMapping
    public AjaxResult edit(@RequestBody TcDbdw tcDbdw) {
        return toAjax(tcDbdwService.updateTcDbdw(tcDbdw));
    }

    /**
     * 删除等保单位
     */
    @ApiOperation(value = "删除等保单位")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcDbdwService.deleteTcDbdwByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcDbdw> util = new ExcelUtil<TcDbdw>(TcDbdw.class);
        List<TcDbdw> tcDbdwList = util.importExcel(file.getInputStream());
        tcDbdwService.importUser(tcDbdwList);
        return AjaxResult.success();
    }
    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcDbdwService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcDbdw> util = new ExcelUtil<TcDbdw>(TcDbdw.class);
        util.importTemplateExcel(response, " 等保单位");
    }
}
