package com.ruoyi.tcZz.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcDtsx;
import com.ruoyi.tcZz.domain.TcDy;
import com.ruoyi.tcZz.domain.TcWljg;
import com.ruoyi.tcZz.service.ITcDyService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 抖音Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api(tags = "抖音")
@RequestMapping("/tcZz/netManage/dy")
public class TcDyController extends BaseController {
    @Autowired
    private ITcDyService tcDyService;

    /**
     * 查询抖音列表
     */
    @ApiOperation(value = "查询抖音列表", response = TcDy.class)
    @GetMapping("/list")
    public TableDataInfo list(TcDy tcDy) {
        startPage();
        List<TcDy> list = tcDyService.selectTcDyList(tcDy);
        return getDataTable(list);
    }

    /**
     * 导出抖音列表
     */
    @ApiOperation(value = "导出抖音列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcDy tcDy) {
        List<TcDy> list = tcDyService.selectTcDyList(tcDy);
        ExcelUtil<TcDy> util = new ExcelUtil<TcDy>(TcDy.class);
        util.exportExcel(response, list, "抖音数据");
    }

    /**
     * 获取抖音详细信息
     */
    @ApiOperation(value = "获取抖音详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcDyService.selectTcDyById(id));
    }

    /**
     * 新增抖音
     */
    @ApiOperation(value = "新增抖音")
    @PostMapping
    public AjaxResult add(@RequestBody TcDy tcDy) {
        return toAjax(tcDyService.insertTcDy(tcDy));
    }

    /**
     * 修改抖音
     */
    @ApiOperation(value = "修改抖音")
    @PutMapping
    public AjaxResult edit(@RequestBody TcDy tcDy) {
        return toAjax(tcDyService.updateTcDy(tcDy));
    }

    /**
     * 删除抖音
     */
    @ApiOperation(value = "删除抖音")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcDyService.deleteTcDyByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcDy> util = new ExcelUtil<TcDy>(TcDy.class);
        List<TcDy> tcDyList = util.importExcel(file.getInputStream());
        tcDyService.importUser(tcDyList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcDyService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcDy> util = new ExcelUtil<TcDy>(TcDy.class);
        util.importTemplateExcel(response, " 抖音");
    }
}
