package com.ruoyi.tcZz.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcAqg;
import com.ruoyi.tcZz.domain.TcJgdw;
import com.ruoyi.tcZz.domain.TcMap;
import com.ruoyi.tcZz.service.ITcMapService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 地图统计Controller
 *
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@Api(tags = "地图统计")
@RequestMapping("/tcZz/networkSecurity/map")
public class TcMapController extends BaseController {
    @Autowired
    private ITcMapService tcMapService;

    /**
     * 查询地图统计列表
     */
    @ApiOperation(value = "查询地图统计列表", response = TcMap.class)
    @GetMapping("/list")
    public TableDataInfo list(TcMap tcMap) {
        startPage();
        List<TcMap> list = tcMapService.selectTcMapList(tcMap);
        return getDataTable(list);
    }

    /**
     * 导出地图统计列表
     */
    @ApiOperation(value = "导出地图统计列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcMap tcMap) {
        List<TcMap> list = tcMapService.selectTcMapList(tcMap);
        ExcelUtil<TcMap> util = new ExcelUtil<TcMap>(TcMap.class);
        util.exportExcel(response, list, "地图统计数据");
    }

    /**
     * 获取地图统计详细信息
     */
    @ApiOperation(value = "获取地图统计详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcMapService.selectTcMapById(id));
    }

    /**
     * 新增地图统计
     */
    @ApiOperation(value = "新增地图统计")
    @PostMapping
    public AjaxResult add(@RequestBody TcMap tcMap) {
        return toAjax(tcMapService.insertTcMap(tcMap));
    }

    /**
     * 修改地图统计
     */
    @ApiOperation(value = "修改地图统计")
    @PutMapping
    public AjaxResult edit(@RequestBody TcMap tcMap) {
        return toAjax(tcMapService.updateTcMap(tcMap));
    }

    /**
     * 删除地图统计
     */
    @ApiOperation(value = "删除地图统计")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcMapService.deleteTcMapByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcMap> util = new ExcelUtil<TcMap>(TcMap.class);
        List<TcMap> tcMapList = util.importExcel(file.getInputStream());
        tcMapService.importUser(tcMapList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcMapService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcMap> util = new ExcelUtil<TcMap>(TcMap.class);
        util.importTemplateExcel(response, " 地图统计");
    }
}
