package com.ruoyi.tcZz.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcAqg;
import com.ruoyi.tcZz.domain.TcMap;
import com.ruoyi.tcZz.domain.TcMtlx;
import com.ruoyi.tcZz.service.ITcMtlxService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 媒体类型Controller
 *
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@Api(tags = "媒体类型")
@RequestMapping("/tcZz/netWorkYq/mtlx")
public class TcMtlxController extends BaseController {
    @Autowired
    private ITcMtlxService tcMtlxService;

    /**
     * 查询媒体类型列表
     */
    @ApiOperation(value = "查询媒体类型列表", response = TcMtlx.class)
    @GetMapping("/list")
    public TableDataInfo list(TcMtlx tcMtlx) {
        startPage();
        List<TcMtlx> list = tcMtlxService.selectTcMtlxList(tcMtlx);
        return getDataTable(list);
    }

    /**
     * 导出媒体类型列表
     */
    @ApiOperation(value = "导出媒体类型列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcMtlx tcMtlx) {
        List<TcMtlx> list = tcMtlxService.selectTcMtlxList(tcMtlx);
        ExcelUtil<TcMtlx> util = new ExcelUtil<TcMtlx>(TcMtlx.class);
        util.exportExcel(response, list, "媒体类型数据");
    }

    /**
     * 获取媒体类型详细信息
     */
    @ApiOperation(value = "获取媒体类型详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcMtlxService.selectTcMtlxById(id));
    }

    /**
     * 新增媒体类型
     */
    @ApiOperation(value = "新增媒体类型")
    @PostMapping
    public AjaxResult add(@RequestBody TcMtlx tcMtlx) {
        return toAjax(tcMtlxService.insertTcMtlx(tcMtlx));
    }

    /**
     * 修改媒体类型
     */
    @ApiOperation(value = "修改媒体类型")
    @PutMapping
    public AjaxResult edit(@RequestBody TcMtlx tcMtlx) {
        return toAjax(tcMtlxService.updateTcMtlx(tcMtlx));
    }

    /**
     * 删除媒体类型
     */
    @ApiOperation(value = "删除媒体类型")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcMtlxService.deleteTcMtlxByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcMtlx> util = new ExcelUtil<TcMtlx>(TcMtlx.class);
        List<TcMtlx> tcMtlxList = util.importExcel(file.getInputStream());
        tcMtlxService.importUser(tcMtlxList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcMtlxService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcMtlx> util = new ExcelUtil<TcMtlx>(TcMtlx.class);
        util.importTemplateExcel(response, " 媒体类型");
    }
}
