package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tcZz.domain.TcAqg;
import com.ruoyi.tcZz.domain.TcTtsum;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcVx;
import com.ruoyi.tcZz.service.ITcVxService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 微信Controller
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api(tags = "微信")
@RequestMapping("/tcZz/netManage/vx")
public class TcVxController extends BaseController
{
    @Autowired
    private ITcVxService tcVxService;

    /**
     * 查询微信列表
     */
    @ApiOperation(value = "查询微信列表",response = TcVx.class)
    @GetMapping("/list")
    public TableDataInfo list(TcVx tcVx)
    {
        startPage();
        List<TcVx> list = tcVxService.selectTcVxList(tcVx);
        return getDataTable(list);
    }

    /**
     * 导出微信列表
     */
    @ApiOperation(value = "导出微信列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcVx tcVx)
    {
        List<TcVx> list = tcVxService.selectTcVxList(tcVx);
        ExcelUtil<TcVx> util = new ExcelUtil<TcVx>(TcVx.class);
        util.exportExcel(response, list, "微信数据");
    }

    /**
     * 获取微信详细信息
     */
    @ApiOperation(value = "获取微信详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcVxService.selectTcVxById(id));
    }

    /**
     * 新增微信
     */
    @ApiOperation(value = "新增微信")
    @PostMapping
    public AjaxResult add(@RequestBody TcVx tcVx)
    {
        return toAjax(tcVxService.insertTcVx(tcVx));
    }

    /**
     * 修改微信
     */
    @ApiOperation(value = "修改微信")
    @PutMapping
    public AjaxResult edit(@RequestBody TcVx tcVx)
    {
        return toAjax(tcVxService.updateTcVx(tcVx));
    }

    /**
     * 删除微信
     */
    @ApiOperation(value = "删除微信")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcVxService.deleteTcVxByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcVx> util = new ExcelUtil<TcVx>(TcVx.class);
        List<TcVx> tcVxList = util.importExcel(file.getInputStream());
        tcVxService.importUser(tcVxList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcVxService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcVx> util = new ExcelUtil<TcVx>(TcVx.class);
        util.importTemplateExcel(response, " 微信");
    }
}
