package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tcZz.domain.TcAqg;
import com.ruoyi.tcZz.domain.TcVx;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcWb;
import com.ruoyi.tcZz.service.ITcWbService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 微博Controller
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api(tags = "微博")
@RequestMapping("/tcZz/netManage/wb")
public class TcWbController extends BaseController
{
    @Autowired
    private ITcWbService tcWbService;

    /**
     * 查询微博列表
     */
    @ApiOperation(value = "查询微博列表",response =TcWb.class )
    @GetMapping("/list")
    public TableDataInfo list(TcWb tcWb)
    {
        startPage();
        List<TcWb> list = tcWbService.selectTcWbList(tcWb);
        return getDataTable(list);
    }

    /**
     * 导出微博列表
     */
    @ApiOperation(value = "导出微博列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcWb tcWb)
    {
        List<TcWb> list = tcWbService.selectTcWbList(tcWb);
        ExcelUtil<TcWb> util = new ExcelUtil<TcWb>(TcWb.class);
        util.exportExcel(response, list, "微博数据");
    }

    /**
     * 获取微博详细信息
     */
    @ApiOperation(value = "获取微博详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcWbService.selectTcWbById(id));
    }

    /**
     * 新增微博
     */
    @ApiOperation(value = "新增微博")
    @PostMapping
    public AjaxResult add(@RequestBody TcWb tcWb)
    {
        return toAjax(tcWbService.insertTcWb(tcWb));
    }

    /**
     * 修改微博
     */
    @ApiOperation(value = "修改微博")
    @PutMapping
    public AjaxResult edit(@RequestBody TcWb tcWb)
    {
        return toAjax(tcWbService.updateTcWb(tcWb));
    }

    /**
     * 删除微博
     */
    @ApiOperation(value = "删除微博")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcWbService.deleteTcWbByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcWb> util = new ExcelUtil<TcWb>(TcWb.class);
        List<TcWb> tcWbList = util.importExcel(file.getInputStream());
        tcWbService.importUser(tcWbList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcWbService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcWb> util = new ExcelUtil<TcWb>(TcWb.class);
        util.importTemplateExcel(response, " 微博");
    }
}
