package com.ruoyi.tcZz.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcWljgtj;
import com.ruoyi.tcZz.domain.TcWpyrwwcl;
import com.ruoyi.tcZz.domain.TcWz;
import com.ruoyi.tcZz.service.ITcWzService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 网站Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api(tags = "网站")
@RequestMapping("/tcZz/netManage/wz")
public class TcWzController extends BaseController {
    @Autowired
    private ITcWzService tcWzService;

    /**
     * 查询网站列表
     */
    @ApiOperation(value = "查询网站列表", response = TcWz.class)
    @GetMapping("/list")
    public TableDataInfo list(TcWz tcWz) {
        startPage();
        List<TcWz> list = tcWzService.selectTcWzList(tcWz);
        return getDataTable(list);
    }

    /**
     * 导出网站列表
     */
    @ApiOperation(value = "导出网站列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcWz tcWz) {
        List<TcWz> list = tcWzService.selectTcWzList(tcWz);
        ExcelUtil<TcWz> util = new ExcelUtil<TcWz>(TcWz.class);
        util.exportExcel(response, list, "网站数据");
    }

    /**
     * 获取网站详细信息
     */
    @ApiOperation(value = "获取网站详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcWzService.selectTcWzById(id));
    }

    /**
     * 新增网站
     */
    @ApiOperation(value = "新增网站")
    @PostMapping
    public AjaxResult add(@RequestBody TcWz tcWz) {
        return toAjax(tcWzService.insertTcWz(tcWz));
    }

    /**
     * 修改网站
     */
    @ApiOperation(value = "修改网站")
    @PutMapping
    public AjaxResult edit(@RequestBody TcWz tcWz) {
        return toAjax(tcWzService.updateTcWz(tcWz));
    }

    /**
     * 删除网站
     */
    @ApiOperation(value = "删除网站")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcWzService.deleteTcWzByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcWz> util = new ExcelUtil<TcWz>(TcWz.class);
        List<TcWz> tcWzList = util.importExcel(file.getInputStream());
        tcWzService.importUser(tcWzList);
        return AjaxResult.success();
    }
    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcWzService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcWz> util = new ExcelUtil<TcWz>(TcWz.class);
        util.importTemplateExcel(response, " 网站");
    }
}
